@@ -6,6 +6,7 @@ from pagetools.cli.analytics.get_codec import get_codec_cli
 from pagetools.cli.transformations.extract import extract_cli
 from pagetools.cli.transformations.regularize import regularize_cli
 from pagetools.cli.transformations.change_index import change_index_cli
+from pagetools.cli.transformations.line2page import line2page_cli
 
 
 @click.group()
@@ -20,4 +21,5 @@ cli.add_command(get_text_count_cli)
 cli.add_command(get_codec_cli)
 cli.add_command(extract_cli)
 cli.add_command(regularize_cli)
-cli.add_command(change_index_cli)
\ No newline at end of file
+cli.add_command(change_index_cli)
+cli.add_command(line2page_cli)
